@@ -1,13 +1,17 @@
 package App::ListPerlReleases;
 
-our $DATE = '2021-05-25'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-05-29'; # DATE
+our $DIST = 'App-ListPerlReleases'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use Perinci::Sub::Gen::AccessTable qw(gen_read_table_func);
+# undetected
+use Sah::Schema::filename;
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -68,7 +72,7 @@ App::ListPerlReleases - List Perl releases
 
 =head1 VERSION
 
-This document describes version 0.002 of App::ListPerlReleases (from Perl distribution App-ListPerlReleases), released on 2021-05-25.
+This document describes version 0.003 of App::ListPerlReleases (from Perl distribution App-ListPerlReleases), released on 2021-05-29.
 
 =head1 SYNOPSIS
 
